@@ -4,7 +4,7 @@
 # framework. See accompanying file "COPYING" for the full copyright and
 # licensing information.
 
-// Return a list of rack IDs, which are P or less positions
+// Return a list of rack IDs that are P or less positions
 // far from the given rack in its row.
 function getProximateRacks ($rack_id, $proximity = 0)
 {
@@ -12,8 +12,7 @@ function getProximateRacks ($rack_id, $proximity = 0)
 	if ($proximity > 0)
 	{
 		$rack = spotEntity ('rack', $rack_id);
-		$rackList = listCells ('rack', $rack['row_id']);
-		doubleLink ($rackList);
+		$rackList = doubleLink (listCells ('rack', $rack['row_id']));
 		$todo = $proximity;
 		$cur_item = $rackList[$rack_id];
 		while ($todo and array_key_exists ('prev_key', $cur_item))
@@ -45,13 +44,13 @@ SELECT
 	p.iif_id,
 	p.type as oif_id,
 	pii.iif_name,
-	d.dict_value as oif_name,
+	poi.oif_name,
 	p.object_id,
 	o.name as object_name
 FROM Port p
 INNER JOIN Object o ON o.id = p.object_id
 INNER JOIN PortInnerInterface pii ON p.iif_id = pii.id
-INNER JOIN Dictionary d ON d.dict_key = p.type
+INNER JOIN PortOuterInterface poi ON poi.id = p.type
 ";
 	// porttype filter (non-strict match)
 	$query .= "
@@ -175,7 +174,7 @@ INNER JOIN (
 	return $ret;
 }
 
-// Return a list of all objects which are possible parents
+// Return a list of all objects that are possible parents
 //    Special case for VMs and VM Virtual Switches
 //        - only select Servers with the Hypervisor attribute set to Yes
 function findObjectParentCandidates ($object_id)
@@ -238,7 +237,7 @@ function renderPopupObjectSelector()
 	echo '<br>';
 	echo "<input type=submit value='Proceed' onclick='".
 		"if (getElementById(\"parents\").value != \"\") {".
-		"	opener.location=\"?module=redirect&page=object&tab=edit&op=linkEntities&object_id=${object_id}&child_entity_type=object&child_entity_id=${object_id}&parent_entity_type=object&parent_entity_id=\"+getElementById(\"parents\").value; ".
+		"	opener.location=\"?module=redirect&page=object&tab=edit&op=linkObjects&object_id=${object_id}&child_entity_type=object&child_entity_id=${object_id}&parent_entity_type=object&parent_entity_id=\"+getElementById(\"parents\").value; ".
 		"	window.close();}'>";
 	echo '</form></div>';
 }
@@ -279,6 +278,19 @@ function handlePopupPortLink()
 		if ($remote_port_info['oif_id'] != $type_remote)
 			commitUpdatePortOIF ($remote_port_info['id'], $type_remote);
 		linkPorts ($port_info['id'], $remote_port_info['id'], $_REQUEST['cable']);
+		// patch cable?
+		if (array_key_exists ('heap_id', $_REQUEST))
+		{
+			// Leave the compatibility constraints check up to the foreign keys.
+			if (0 != $heap_id = genericAssertion ('heap_id', 'uint0'))
+			{
+				$heaps = getPatchCableHeapSummary();
+				if (commitModifyPatchCableAmount ($heap_id, -1))
+					showSuccess ('consumed a patch cable from ' . formatPatchCableHeapAsPlainText ($heaps[$heap_id]));
+				else
+					showError ('failed to consume a patch cable');
+			}
+		}
 		showOneLiner 
 		(
 			8, 
@@ -440,6 +452,11 @@ function renderPopupPortSelector()
 	{
 		echo getSelect ($spare_ports, array ('name' => 'remote_port', 'size' => getConfigVar ('MAXSELSIZE')), NULL, FALSE);
 		echo "<p>Cable ID: <input type=text id=cable name=cable>";
+		// suggest patch cables where it makes sense
+		$heaps = getPatchCableHeapOptionsForOIF ($port_info['oif_id']);
+		if (count ($heaps))
+			// Use + instead of array_merge() to avoid renumbering the keys.
+			echo '<p>Patch cable: ' . getSelect (array (0 => 'none') + $heaps, array ('name' => 'heap_id'));
 		echo "<p><input type='submit' value='Link' name='do_link'>";
 	}
 	finishPortlet();
